[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# REMSOL

## Overview

REMSOL (Rust-based Electromagnetic Multi-layer Solver) is a software package for finding electromagnetic modes in 1D multi-layered media. It is written in Rust for speed and provides a Python interface for ease of use.

## Installation

The package is availavlbe on PyPi, so you can install it using pip:

```bash
pip install remsol
```

if you want to build the package from source, you can check out the [Documentation](https://mpasson.github.io/REMSOL/intro.html#building-from-source)

## How to use it

Check the examples in the [Documentation](https://mpasson.github.io/REMSOL/examples/examples.html).

## Contributing

Contributions are welcome. Plase feel free to open an issue or a pull request.
